@@ -68,7 +68,7 @@
 #' 
 #' @param dosing The dosing object for more complicated scenarios. Defaults to
 #' repeated \code{daily.dose} spread out over \code{doses.per.day}
-#' 
+#'
 #' @param ... Additional arguments passed to model solver (default of
 #' \code{\link{solve_pbtk}}).
 #'
@@ -79,6 +79,8 @@
 #' \item{the.day}{The day the average concentration comes within 100 * p
 #' percent of the true steady state concentration.}
 #'
+#' @seealso \code{\link{calc_analytic_css}}
+#'
 #' @author Robert Pearce, John Wambaugh
 #'
 #' @keywords Steady-State
@@ -107,6 +109,7 @@
 #'
 #' print(c.vs.t)
 #' 
+#' @importFrom purrr compact 
 #' @export calc_css
 calc_css <- function(chem.name=NULL,
                     chem.cas=NULL, 
@@ -171,7 +174,8 @@ calc_css <- function(chem.name=NULL,
   # We only want to call the parameterize function once:
   if (is.null(parameters))
   {
-    parameters <- do.call(parameterize_function,list(
+    parameters <- do.call(parameterize_function,
+                          args=purrr::compact(c(list(
       chem.cas=chem.cas,
       chem.name=chem.name,
       dtxsid=dtxsid,
@@ -179,7 +183,7 @@ calc_css <- function(chem.name=NULL,
       default.to.human=default.to.human,
       suppress.messages=suppress.messages,
       adjusted.Funbound.plasma=adjusted.Funbound.plasma,
-      regression=regression)) 
+      regression=regression))))
   }
 
   if (is.null(dosing))
@@ -221,15 +225,18 @@ calc_css <- function(chem.name=NULL,
   monitor.vars <- unique(c(state.vars, target))
   
 # Initial call to solver, maybe we'll get lucky and achieve rapid steady-state
-  out <- solve_model(parameters=parameters,
+  out <- do.call(solve_model,
+# we use purrr::compact to drop NULL values from arguments list:
+      args=purrr::compact(c(list(    
+      parameters=parameters,
     model=model, 
     dosing=dosing,
     suppress.messages=TRUE,
     days=days,
     output.units = output.units,
     restrictive.clearance=restrictive.clearance,
-    monitor.vars=monitor.vars,
-    ...)
+    monitor.vars=monitor.vars),
+    ...)))
     
 # Make sure we have the compartment we need: 
   if (!(target %in% colnames(out))) stop(paste(
@@ -256,8 +263,11 @@ calc_css <- function(chem.name=NULL,
     #  additional.days <- additional.days * 3
     #}
     total.days <- total.days + additional.days
-    
-    out <- solve_model(parameters=parameters,
+
+  out <- do.call(solve_model,
+# we use purrr::compact to drop NULL values from arguments list:
+      args=purrr::compact(c(list(    
+      parameters=parameters,
       model=model,
       initial.values = Final_Conc[state.vars],  
       dosing=dosing,
@@ -266,8 +276,7 @@ calc_css <- function(chem.name=NULL,
       restrictive.clearance=restrictive.clearance,
       monitor.vars=monitor.vars,    
       suppress.messages=TRUE,
-      restrictive.clearance=restrictive.clearance,
-      ...)
+      ...))))
     Final_Conc <- out[dim(out)[1],monitor.vars]
   
     if(total.days > 36500) break 
