@@ -1,38 +1,71 @@
-#' Lump tissue parameters
+#' Lump tissue parameters into model compartments
+#'                                               
+#' This function takes the tissue:plasma partition coefficients from 
+#' \code{\link{predict_partitioning_schmitt}} along with the tissue-specific
+#' volumes and flows and aggregates (or "lumps") them
+#' according to the needed scheme of toxicokinetic model tissue comparments.
 #' 
-#' This function takes the parameters from predict_partitioning_schmitt and 
-#' lumps the partition coefficients along with the volumes and flows based on 
-#' the given tissue list. It is useful in Monte Carlo simulation of individual
-#' partition coefficients when calculating the rest of body partition
-#' coefficient.
+#' \code{\link{predict_partitioning_schmitt}} makes tissue-specific predictions
+#' drawing from those tissues described in \code{\link{tissue.data}}. Since
+#' different physiologically-based toxicokinetic (PBTK) models use diffeent 
+#' schemes for rganizing the
+#' tissues of the body into differing compartments (for example, "rapidly
+#' perfused tissues"), this function lumps tissues into
+#' compartments as specified by the argument 'tissuelist'. Aggregate flows, 
+#' volumes, and partition coefficients are provided for the
+#' lumped tissue compartments. Flows and volumes are summed while
+#' partition coefficients is calculated using averaging weighted by 
+#' species-specific tissue volumes.
+#'
+#' The name of each entry in 'tissuelist' is its own compartment. The
+#' modelinfo_MODEL.R file corresponding to the model specified by argument
+#' 'model' includes both a 'tissuelist' describing to the model's 
+#' compartmentallumping schme as well as a vector of 'tissuenames' specifying 
+#' all tissues to be lumped into those compartments.
+#'
+#' Alternatively the 'tissuelist' and 'tissuenames' can also be manually
+#' specified for alternate lumping schemes not necessarily related to a
+#' pre-made httk model. For example,
+#' tissuelist<-list(Rapid=c("Brain","Kidney")).
 #' 
-#' This function returns the flows, volumes, and partition coefficients for the
-#' lumped tissues specified in tissue list Ktissue2plasma -- tissue to free
-#' plasma concentration partition coefficients for every tissue specified by 
-#' Schmitt (2008) (the tissue.data table) tissuelist -- a list of character 
-#' vectors, the name of each entry in the list is its own compartment.
-#' The tissues in the alltissues vector are the Schmitt (2008) tissues that are
-#' to be considered in the lumping process. The tissuelist can also be manually
-#' specified for alternate lumping schemes: for example,
-#' tissuelist<-list(Rapid=c("Brain","Kidney")) specifies the flow.col and
-#' vol.col in the tissuedata.table. 
+#' The tissues contained in 'tissuenames' that are unused in 'tissuelist' 
+#' are aggregated into a single compartment termed
+#' "rest".
+#'
+#' NOTE: The partition coefficients of lumped compartments vary according to
+#' individual and species differences since the volumes of the consitutent 
+#' tissues may vary.
 #' 
 #' @param Ktissue2pu.in List of partition coefficients from
-#' predict_partitioning_schmitt.
+#' \code{predict_partitioning_schmitt}. The tissues named in this list are 
+#' lumped into the compartments specified by \code{tissuelist} unless they are
+#' not present the specified \code{model}'s associated \code{alltissues}.
+#'
 #' @param parameters A list of physiological parameters including flows and
-#' volumes for tissues in \code{tissuelist}
+#' volumes for tissues named in \code{Ktissue2pu.in}
+#'
 #' @param tissuelist Manually specifies compartment names and tissues, which
 #' override the standard compartment names and tissues that are usually
 #' specified in a model's associated modelinfo file. Remaining tissues in the
 #' model's associated \code{alltissues} listing are lumped in the rest of the body.
+#'
 #' @param species Species desired (either "Rat", "Rabbit", "Dog", "Mouse", or
 #' default "Human").
-#' @param tissue.vols A list of volumes for tissues in \code{tissuelist}
-#' @param tissue.flows A list of flows for tissues in \code{tissuelist}
+#'
+#' @param tissue.vols A list of volumes for tissues in \code{tissuelist}.
+#'
+#' @param tissue.flows A list of flows for tissues in \code{tissuelist}.
+#' 
+#' @param tissuenames A list of tissue names in \code{tissuenames}.
+#'
 #' @param model Specify which model (and therefore which tissues) are being 
-#' considered
+#' considered.
+#'
 #' @param suppress.messages Whether or not the output message is suppressed.
 #'
+#' @seealso \code{\link{predict_partitioning_schmitt}}
+#' @seealso \code{\link{tissue.data}}
+#'
 #' @return \item{Krbc2pu}{Ratio of concentration of chemical in red blood cells
 #' to unbound concentration in plasma.} \item{Krest2pu}{Ratio of concentration
 #' of chemical in rest of body tissue to unbound concentration in plasma.}
@@ -49,14 +82,17 @@
 #' high-throughput predictions of chemical distribution to tissues." Journal of
 #' pharmacokinetics and pharmacodynamics 44.6 (2017): 549-565.
 #'
-#' @keywords Parameter
+#' @keywords Parameter pbtk
 #' 
 #' @examples
 #' 
-#' pcs <- predict_partitioning_schmitt(chem.name='bisphenola')
-#' tissuelist <- list(liver=c("liver"),kidney=c("kidney"),lung=c("lung"),gut=c("gut")
-#' ,muscle.bone=c('muscle','bone'))
-#' lump_tissues(pcs,tissuelist=tissuelist)
+#'  pcs <- predict_partitioning_schmitt(chem.name='bisphenola')
+#'  tissuelist <- list(
+#'    liver=c("liver"),
+#'    rapid=c("lung","kidney","muscle","brain"),
+#'    fat=c("adipose"),
+#'    slow=c('bone'))
+#'  lump_tissues(pcs,tissuelist=tissuelist)
 #' 
 #' @export lump_tissues
 lump_tissues <- function(Ktissue2pu.in,
@@ -65,6 +101,7 @@ lump_tissues <- function(Ktissue2pu.in,
                          species="Human",
                          tissue.vols=NULL,
                          tissue.flows=NULL,
+                         tissuenames=NULL,
                          model="pbtk",
                          suppress.messages=FALSE)
 {
@@ -76,35 +113,46 @@ lump_tissues <- function(Ktissue2pu.in,
   Tissue <- Species <- varable <- Parameter <- variable <- NULL
 #End R CMD CHECK appeasement.
 
-  #run some basic checks for naming consistency and completeness on input: 
-  if ((is.null(model)) & is.null(parameters))
-    stop('The "model" variable must be specified if a complete set of
-          "parameters" is not otherwise provided.')
+#  #run some basic checks for naming consistency and completeness on input: 
+#  if ((is.null(model)) & is.null(parameters))
+#    stop('The "model" variable must be specified if a complete set of
+#          "parameters" is not otherwise provided.')
   
-  if (is.null(model)) stop("Model must be specified.")
-  model <- tolower(model)
-  if (!(model %in% names(model.list)))            
+  if (is.null(model) & is.null(tissuelist)) 
+    stop("Model or tissuelist must be specified.")
+  if (is.null(tissuelist))
   {
-    stop(paste("Model",model,"not available. Please select from:",
-      paste(names(model.list),collapse=", ")))
-  } else {
-    #Before using tissuelist, make sure it is initialized with the tissuelist
-    #entry from the modelinfo file of interest. If tissuelist is already manually
-    #specified, it takes priority.
-    if (is.null(tissuelist)){
-      tissuelist <- model.list[[model]]$tissuelist
+    model <- tolower(model)
+    if (!(model %in% names(model.list)))            
+    {
+      stop(paste("Model",model,"not available. Please select from:",
+        paste(names(model.list),collapse=", ")))
+    } else {
+      # Before using tissuelist, make sure it is initialized with the tissuelist
+      # entry from the relevant modelinfo file. If tissuelist is already manually
+      # specified, it takes priority.
+      if (is.null(tissuelist)){
+        tissuelist <- model.list[[model]]$tissuelist
+      }
+      
+      # List all tissues/compartments for which a model needs partitioning
+      # information, regardless of whether the tissue/compartment is to be lumped 
+      # or not.  
+      tissuenames <- sort(unique(model.list[[model]]$alltissues))
     }
-    
-    # List all tissues/compartments for which a model needs partitioning
-    # information, regardless of whether the tissue/compartment is to be lumped 
-    # or not.  
-    tissuenames <- sort(unique(model.list[[model]]$alltissues))
+  } else {
+    # get the list of tissues for which we have partition coefficients (names 
+    # are expected to be in the form of "K[TISSUE]2pu"):
+    tissuenames <- 
+      lapply(names(Ktissue2pu.in),
+             function(x) strsplit(strsplit(x,"K")[[1]][2],"2pu")[[1]][1])
+    if ("rbc" %in% tissuenames) tissuenames[tissuenames=="rbc"] <- 
+        "red blood cells"
   }
 
   if (!all(unlist(tissuelist) %in% tissuenames))
   {
-    stop("Not all of the tissues/compartments specified in \"tissuelist\" 
-are present in the entries of the associated modelinfo file's \"alltissues.\"")
+    stop("Some of the tissues/compartments specified in \"tissuelist\" are missing either from Ktissue2pu.in or the specified model's associated modelinfo file's \"alltissues.\"")
   }
   
   #Check to make sure the tissuelist is a list of character vectors.
@@ -294,7 +342,8 @@ NULL if the model is a 1 compartment model where no lumping is necessary.")
       	
       		#if this.flow or this.vol still NULL after checking all sources
       	if (!suppress.messages & 
-          ((length(this.flow) == 0) | (length(this.vol)==0)))
+          ((length(this.flow) == 0) | (length(this.vol)==0) |
+           !is.numeric(this.flow) | !is.numeric(this.vol)))
         {
       	  warning("A flow or volume associated with the ",this.tissue," and 
       	passed to lump_tissues is undefined. You may need to check to make
@@ -326,7 +375,19 @@ NULL if the model is a 1 compartment model where no lumping is necessary.")
   		}
 # Add the flow for this tissue to the lumped tissue:                             
   		flow[[this.lumped.tissue]] <- flow[[this.lumped.tissue]] + this.flow 
-		}
+  		#if check if we messed up flow or vol:
+  		if (!suppress.messages & 
+  		    ((length(flow[[this.lumped.tissue]]) == 0) | 
+  		     (length(vol[[this.lumped.tissue]])==0) |
+  		     !is.numeric(flow[[this.lumped.tissue]]) | 
+  		     !is.numeric(vol[[this.lumped.tissue]])))
+  		{
+  		  warning("A flow or volume associated with the ",this.tissue," and 
+      	passed to lump_tissues is undefined. You may need to check to make
+      	sure the input tissue information, if no tissue volume or flow is
+      	intended to be left out.")
+  		}		
+  	}
 #Calculate the average partition coefficient by dividing by the total volume of
 #the lumped tissue
 	  if (length(vol[[this.lumped.tissue]]) > 0){
@@ -400,5 +461,5 @@ NULL if the model is a 1 compartment model where no lumping is necessary.")
   names(flow)[names(flow) == 'liver'] <- 'total.liver'
   names(flow) <- paste('Q',names(flow),'f',sep='')
     
- 	return(c(Ktissue2pu.out,vol,flow))
+ 	return(lapply(c(Ktissue2pu.out,vol,flow),set_httk_precision))
 }
