@@ -1,10 +1,14 @@
 #' Parameters for a generic physiologically-based toxicokinetic model
 #' 
-#' Generate a chemical- and species-specific set of model parameters, 
-#' including tissue:plasma partition coefficients (via Schmitt (2008)'s method
-#' as modified by Pearce et al. (2017)) and organ volumes and flows 
-#' (from table \code{\link{physiology.data}}) for an arbitrary tissue lumping 
-#' scheme (tissues  must be described in table \code{\link{tissue.data}}).
+#' Generate a chemical- and species-specific set of PBPK model parameters.
+#' Parameters include 
+#' tissue:plasma partition coefficients, organ volumes, and flows 
+#' for the tissue lumping scheme specified by argument tissuelist.
+#' Tissure:(fraction unbound in) plasma partitition coefficients are predicted
+#' via Schmitt (2008)'s method as modified by Pearce et al. (2017) using
+#' \code{\link{predict_partitioning_schmitt}}. Organ volumes and flows are
+#' retrieved from table \code{\link{physiology.data}}.
+#' Tissues must be described in table \code{\link{tissue.data}}. 
 #'
 #' By default, this function initializes the parameters needed in the functions 
 #' \code{\link{solve_pbtk}}, \code{\link{calc_css}}, and others using the httk 
@@ -19,6 +23,7 @@
 #' @param dtxsid EPA's 'DSSTox Structure ID (\url{https://comptox.epa.gov/dashboard})   
 #' -- the chemical must be identified by either CAS, name, or DTXSIDs
 #' 
+#' 
 #' @param species Species desired (either "Rat", "Rabbit", "Dog", "Mouse", or
 #' default "Human").
 #' 
@@ -50,9 +55,14 @@
 #' @param restrictive.clearance In calculating hepatic.bioavailability, protein
 #' binding is not taken into account (set to 1) in liver clearance if FALSE.
 #' 
-#' @param minimum.Funbound.plasma Monte Carlo draws less than this value are set 
-#' equal to this value (default is 0.0001 -- half the lowest measured Fup in our
-#' dataset).
+#' @param minimum.Funbound.plasma \eqn{f_{up}} is not allowed to drop below
+#' this value (default is 0.0001).                                
+#'                                                                                             
+#' @param million.cells.per.gliver Hepatocellularity (defaults to 110 10^6 cells/g-liver, from Carlile et al. (1997))
+#'
+#' @param liver.density Liver density (defaults to 1.05 g/mL from International Commission on Radiological Protection (1975))
+#'
+#' @param kgutabs Oral absorption rate from gut (defaults to 2.18 1/h from Wambaugh et al. (2018))
 #' 
 #' @return \item{BW}{Body Weight, kg.} 
 #' \item{Clmetabolismc}{Hepatic Clearance, L/h/kg BW.} 
@@ -92,6 +102,7 @@
 #' \item{Vlungc}{Volume of the lungs per kg body weight, L/kg BW.}
 #' \item{Vrestc}{ Volume of the rest of the body per kg body weight, L/kg BW.}
 #' \item{Vvenc}{Volume of the veins per kg body weight, L/kg BW.} 
+#'
 #' @author John Wambaugh and Robert Pearce
 #'
 #' @references 
@@ -109,9 +120,33 @@
 #' (2008). Hepatocellular binding of drugs: correction for unbound fraction in
 #' hepatocyte incubations using microsomal binding or drug lipophilicity data.
 #' Drug Metabolism and Disposition 36(7), 1194-7, 10.1124/dmd.108.020834.
-#' @keywords Parameter pbtk
-#' @examples
+#'
+#' Carlile, David J., Katayoun Zomorodi, and J. Brian Houston. "Scaling factors 
+#' to relate drug metabolic clearance in hepatic microsomes, isolated 
+#' hepatocytes, and the intact liver: studies with induced livers involving 
+#' diazepam." Drug metabolism and disposition 25.8 (1997): 903-911.
 #' 
+#' International Commission on Radiological Protection. Report of the task 
+#' group on reference man. Vol. 23. Pergamon, Oxford. 1975.
+#'
+#' Wambaugh, John F., et al. "Evaluating in vitro-in vivo extrapolation of 
+#' toxicokinetics." Toxicological Sciences 163.1 (2018): 152-169.
+#' 
+#' @keywords Parameter pbtk
+#'
+#' @seealso \code{\link{solve_pbtk}}
+#'
+#' @seealso \code{\link{calc_analytic_css_pbtk}}
+#'
+#' @seealso \code{\link{predict_partitioning_schmitt}}
+#'
+#' @seealso \code{\link{apply_clint_adjustment}}
+#'
+#' @seealso \code{\link{tissue.data}}
+#'
+#' @seealso \code{\link{physiology.data}}
+#'
+#' @examples
 #' 
 #'  parameters <- parameterize_pbtk(chem.cas='80-05-7')
 #' 
@@ -122,9 +157,6 @@
 #'                       lung=c("lung"),gut=c("gut"),slow=c("bone"))
 #'  parameterize_pbtk(chem.name="Bisphenol a",species="Rat",default.to.human=TRUE,
 #'                    tissuelist=compartments) 
-#'  
-#'  
-#' 
 #' @export parameterize_pbtk
 parameterize_pbtk <- function(
                        chem.cas=NULL,
@@ -144,7 +176,11 @@ parameterize_pbtk <- function(
                        regression=TRUE,
                        suppress.messages=FALSE,
                        restrictive.clearance=TRUE,
-                       minimum.Funbound.plasma=0.0001)
+                       minimum.Funbound.plasma=0.0001,
+                       million.cells.per.gliver= 110, # 10^6 cells/g-liver Carlile et al. (1997)
+                       liver.density= 1.05, # g/mL International Commission on Radiological Protection (1975)
+                       kgutabs = 2.18 # 1/h, Wambaugh et al. (2018)
+                       )
 {
   #Give a binding to the physiology.data
   physiology.data <- physiology.data
@@ -163,72 +199,60 @@ parameterize_pbtk <- function(
   chem.name <- out$chem.name
   dtxsid <- out$dtxsid
   
-  # Clint has units of uL/min/10^6 cells
-  Clint.db <- try(get_invitroPK_param(
-                    "Clint",
-                    species,
-                    chem.cas=chem.cas),
-                silent=TRUE)
-  # Check that the trend in the CLint assay was significant:
-  Clint.pValue <- try(get_invitroPK_param(
-                        "Clint.pValue",
-                        species,
-                        chem.cas=chem.cas),
-                    silent=TRUE)
-  if ((is(Clint.db,"try-error") & default.to.human) || 
-      force.human.clint.fup) 
-  {
-    Clint.db <- try(get_invitroPK_param(
-                      "Clint",
-                      "Human",
-                      chem.cas=chem.cas),
-                  silent=TRUE)
-    Clint.pValue <- try(get_invitroPK_param(
-                          "Clint.pValue",
-                          "Human",
-                          chem.cas=chem.cas),
-                      silent=TRUE)
+# Get the intrinsic hepatic clearance:  
+  Clint.list <- get_clint(
+      dtxsid=dtxsid,
+      chem.name=chem.name,
+      chem.cas=chem.cas,
+      species=species,
+      default.to.human=default.to.human,
+      force.human.clint=force.human.clint.fup,
+      clint.pvalue.threshold=clint.pvalue.threshold,
+      suppress.messages=suppress.messages) 
+  Clint.point <- Clint.list$Clint.point
+  Clint.dist <- Clint.list$Clint.dist
 
-    warning(paste(species,"coerced to Human for metabolic clearance data."))
-  }
-  if (is(Clint.db,"try-error")) 
-    stop("Missing metabolic clearance data for given species. \n\
-         Set default.to.human to true to substitute human value.")
-  # Check if clint is a point value or a distribution, if a distribution, use the median:
-  if (nchar(Clint.db) - nchar(gsub(",","",Clint.db))==3) 
-  {
-    Clint.dist <- Clint.db
-    Clint<- as.numeric(strsplit(Clint.db,",")[[1]][1])
-    Clint.pValue <- as.numeric(strsplit(Clint.db,",")[[1]][4])
-    if (!suppress.messages) warning("Clint is provided as a distribution.")
-  } else {
-    Clint <- Clint.db
-    Clint.dist <- NA
-  }
-  if (!is.na(Clint.pValue) & Clint.pValue > clint.pvalue.threshold) Clint  <- 0
+# Get phys-chemical properties:
+  MW <- get_physchem_param("MW",chem.cas=chem.cas) #g/mol
+  # acid dissociation constants
+  pKa_Donor <- suppressWarnings(get_physchem_param(
+    "pKa_Donor",
+    chem.cas=chem.cas)) 
+  # basic association cosntants
+  pKa_Accept <- suppressWarnings(get_physchem_param(
+    "pKa_Accept",
+    chem.cas=chem.cas)) 
+  # Octanol:water partition coefficient
+  Pow <- 10^get_physchem_param(
+    "logP",
+    chem.cas=chem.cas) 
+    
+# Calculate unbound fraction of chemical in the hepatocyte intrinsic 
+# clearance assay (Kilford et al., 2008)
+  Fu_hep <- calc_hep_fu(parameters=list(
+    Pow=Pow,
+    pKa_Donor=pKa_Donor,
+    pKa_Accept=pKa_Accept)) # fraction 
 
+# Correct for unbound fraction of chemical in the hepatocyte intrinsic 
+# clearance assay (Kilford et al., 2008)
+  if (adjusted.Clint) Clint.point <- apply_clint_adjustment(
+                               Clint.point,
+                               Fu_hep=Fu_hep,
+                               suppress.messages=suppress.messages)
+                                   
 # Predict the PCs for all tissues in the tissue.data table:
   schmitt.params <- parameterize_schmitt(
                       chem.cas=chem.cas,
                       species=species,
                       default.to.human=default.to.human,
                       force.human.fup=force.human.clint.fup,
-                      suppress.messages=TRUE,
+                      suppress.messages=suppress.messages,
+                      adjusted.Funbound.plasma=adjusted.Funbound.plasma,
                       minimum.Funbound.plasma=minimum.Funbound.plasma)
-
-# Correct for unbound fraction of chemical in the hepatocyte intrinsic 
-# clearance assay (Kilford et al., 2008)
-  Fu_hep <- calc_hep_fu(parameters=schmitt.params[c(
-                "Pow","pKa_Donor","pKa_Accept")])  # fraction
-  if (adjusted.Clint) 
-  {
-    Clint <- Clint / Fu_hep
-    if (!suppress.messages) 
-    {
-      warning('Clint adjusted for in vitro partioning (Kilford, 2008).')
-    }
-  }
-
+       
+  fup <- schmitt.params$Funbound.plasma
+  
   PCs <- predict_partitioning_schmitt(
     parameters=schmitt.params,
     species=species,
@@ -245,23 +269,6 @@ parameterize_pbtk <- function(
     species=species,
     model="pbtk",
     suppress.messages=suppress.messages)
-       
-  if (schmitt.params$unadjusted.Funbound.plasma == 0)
-    if (tolower(species) == "human" | default.to.human) {
-      stop("Fraction unbound = 0, cannot predict partitioning.")
-    } else {
-      stop("Fraction unbound = 0, cannot predict partitioning. Perhaps try default.to.human=TRUE.")
-    }
-  
-  # Check to see if we should use the in vitro fup assay correction:  
-  if (adjusted.Funbound.plasma)
-  {
-    fup <- schmitt.params$Funbound.plasma
-    if (!suppress.messages) warning('Funbound.plasma adjusted for in vitro partioning (Pearce, 2017).')
-  } else fup <- schmitt.params$unadjusted.Funbound.plasma
-  
-  # Restrict the value of fup:
-  if (fup < minimum.Funbound.plasma) fup <- minimum.Funbound.plasma
 
   Fgutabs <- try(get_invitroPK_param(
                    "Fgutabs",
@@ -287,23 +294,9 @@ parameterize_pbtk <- function(
   this.phys.data <- physiology.data[,phys.species]
   names(this.phys.data) <- physiology.data[,1]
   
-  MW <- get_physchem_param("MW",chem.cas=chem.cas) #g/mol
-  # acid dissociation constants
-  pKa_Donor <- suppressWarnings(get_physchem_param(
-    "pKa_Donor",
-    chem.cas=chem.cas)) 
-  # basic association cosntants
-  pKa_Accept <- suppressWarnings(get_physchem_param(
-    "pKa_Accept",
-    chem.cas=chem.cas)) 
-  # Octanol:water partition coefficient
-  Pow <- 10^get_physchem_param(
-    "logP",
-    chem.cas=chem.cas) 
-  
   outlist <- list()
   # Begin flows:
-  #mL/min/kgBW converted to L/h/kgBW:
+  #mL/min/kgBW^(3/4) converted to L/h/kgBW^(3/4):
   QGFRc <- this.phys.data["GFR"]/1000*60 
   Qcardiacc = this.phys.data["Cardiac Output"]/1000*60 
   flows <- unlist(lumped_params[substr(names(lumped_params),1,1) == 'Q'])
@@ -333,7 +326,7 @@ parameterize_pbtk <- function(
   BW <- this.phys.data["Average BW"]
   hematocrit = this.phys.data["Hematocrit"]
   outlist <- c(outlist,list(BW = as.numeric(BW),
-                            kgutabs = 2.18, # 1/h
+                            kgutabs = kgutabs, # 1/h
                             Funbound.plasma = fup, # unitless fraction
                             Funbound.plasma.dist = schmitt.params$Funbound.plasma.dist,
                             hematocrit = as.numeric(hematocrit), # unitless ratio
@@ -351,18 +344,17 @@ parameterize_pbtk <- function(
 
   outlist <- c(
     outlist,
-    list(Clint=Clint,
+    list(Clint=Clint.point,
          Clint.dist = Clint.dist,
          Fhep.assay.correction=Fu_hep,  # fraction 
          Clmetabolismc= as.numeric(calc_hep_clearance(
            hepatic.model="unscaled",
            parameters=list(
-             Clint=Clint, #uL/min/10^6 cells
+             Clint=Clint.point, #uL/min/10^6 cells
              Funbound.plasma=fup, # unitless fraction
-             Fhep.assay.correction=Fu_hep,
              Rblood2plasma = outlist$Rblood2plasma, 
-             million.cells.per.gliver= 110, # 10^6 cells/g-liver
-             liver.density= 1.05, # g/mL
+             million.cells.per.gliver = million.cells.per.gliver, # 10^6 cells/g-liver
+             liver.density = liver.density, # g/mL
              Dn=0.17,
              BW=BW,
              Vliverc=lumped_params$Vliverc, #L/kg
@@ -370,8 +362,8 @@ parameterize_pbtk <- function(
                (lumped_params$Qtotal.liverf*as.numeric(Qcardiacc))/1000*60),
            suppress.messages=TRUE,
            restrictive.clearance=restrictive.clearance)), #L/h/kg BW
-         million.cells.per.gliver=110, # 10^6 cells/g-liver
-         liver.density=1.05, # g/mL
+         million.cells.per.gliver = million.cells.per.gliver, # 10^6 cells/g-liver
+         liver.density = liver.density, # g/mL
          Fgutabs=Fgutabs)) 
   
   if (adjusted.Funbound.plasma) 
@@ -380,7 +372,6 @@ parameterize_pbtk <- function(
       schmitt.params$Funbound.plasma.adjustment
   } else outlist["Funbound.plasma.adjustment"] <- NA
    
-
   # alphabetize:
   outlist <- outlist[order(tolower(names(outlist)))]
   
