@@ -56,6 +56,14 @@
 #'
 #' @keywords Parameter schmitt
 #'
+#' @seealso \code{\link{predict_partitioning_schmitt}}
+#'
+#' @seealso \code{\link{tissue.data}}
+#'
+#' @seealso \code{\link{calc_ma}}
+#'
+#' @seealso \code{\link{apply_fup_adjustment}}
+#'
 #' @references 
 #' Pearce, Robert G., et al. "Httk: R package for high-throughput 
 #' toxicokinetics." Journal of statistical software 79.4 (2017): 1.
@@ -81,7 +89,6 @@
 #' parameterize_schmitt(chem.name='bisphenola')
 #' 
 #' @export parameterize_schmitt
-
 parameterize_schmitt <- function(chem.cas=NULL,
                           chem.name=NULL,
                           dtxsid = NULL,
@@ -109,8 +116,9 @@ parameterize_schmitt <- function(chem.cas=NULL,
       is.null(parameters)) 
     stop('Parameters, chem.name, chem.cas, or dtxsid must be specified.')
 
-# Look up the chemical name/CAS, depending on what was provide:
-  if (any(is.null(chem.cas),is.null(chem.name),is.null(dtxsid)))
+# Look up the chemical name/CAS, depending on what was provided:
+  if (is.null(parameters))
+    if (any(is.null(chem.cas),is.null(chem.name),is.null(dtxsid)))
   {
     out <- get_chem_id(
             chem.cas=chem.cas,
@@ -142,161 +150,184 @@ parameterize_schmitt <- function(chem.cas=NULL,
 #        paste(required.params[!(required.params%in%names(parameters))],
 #          collapse=", "),
 #        "in parameterize_schmitt")
-        
-  # unitless fraction of chemical unbound with plasma
-  fup.db <- try(
-              get_invitroPK_param(
-                "Funbound.plasma",
-                species,
-                chem.cas=chem.cas,
-                chem.name=chem.name,
-                dtxsid=dtxsid),
-              silent=TRUE)
-  if ((is(fup.db,"try-error") & default.to.human) || force.human.fup) 
+
+  # Check to see if these parameters have been provided:
+  if (!is.null(parameters))
   {
-    fup.db <- try(
-                get_invitroPK_param(
-                  "Funbound.plasma",
-                  "Human",
-                  chem.cas=chem.cas,
-                  chem.name=chem.name,
-                  dtxsid=dtxsid),
-                silent=TRUE)
-    if (!suppress.messages) 
-      warning(paste(species,"coerced to Human for protein binding data."))
-  }
-  if (is(fup.db,"try-error")) 
-    stop("Missing protein binding data for given species. Set default.to.human to true to substitute human value.")
-  if (!is.null(parameters))
-    if ("Fraction_unbound_plasma" %in% names(parameters))
-      fup.db <- parameters$Fraction_unbound_plasma
-  
-  Pow <- 10^get_physchem_param("logP",chem.cas=chem.cas)
-  if (!is.null(parameters))
+    if ("Funbound.plasma.dist" %in% names(parameters))
+    {
+      fup.dist <- parameters$Funbound.plasma.dist
+    } else {
+      fup.dist <- NA
+    }
+    if ("Funbound.plasma" %in% names(parameters))
+    {
+      fup.point <- parameters$Funbound.plasma
+    } else {
+      fup.point <- NA
+    }
     if ("Pow" %in% names(parameters))
+    {
       Pow <- parameters$Pow
-        
-  pKa_Donor <- suppressWarnings(get_physchem_param(
+    } else {
+      Pow <- NA
+    }
+    if ("pKa_Donor" %in% names(parameters))
+    {
+      pKa_Donor <- parameters$pKa_Donor
+    } else {
+      pKa_Donor <- -999
+    }
+    if ("pKa_Accept" %in% names(parameters))
+    {
+      pKa_Accept <- parameters$pKa_Accept
+    } else {
+      pKa_Accept <- -999
+    }
+    if ("MA" %in% names(parameters))
+    {
+      MA <- parameters$MA
+    } else {
+      MA <- NA
+    }
+    if ("Fprotein.plasma" %in% names(parameters))
+    {
+      Fprotein <- parameters$Fprotein.plasma
+    } else {
+      Fprotein <- NA
+    }
+    if ("plasma.pH" %in% names(parameters))
+    {
+      plasma.pH <- parameters$plasma.pH
+    } else {
+      plasma.pH <- NA
+    }
+    if ("alpha" %in% names(parameters))
+    {
+      alpha <- parameters$alpha
+    } else {
+      alpha <- NA
+    }
+# If not, mark them incomplete and try to retrieve them.
+# (Note that "NA" is an acceptable value for pKa's, so use -999)
+  } else {
+    fup.point <- NA
+    fup.dist <-NA
+    Pow <- NA
+    pKa_Donor <- -999
+    pKa_Accept <- -999
+    MA <- NA
+    Fprotein <- NA
+    plasma.pH <- NA
+    alpha <- NA
+  }
+    
+  if (is.na(Pow))
+  {
+    Pow <- 10^get_physchem_param("logP",chem.cas=chem.cas)
+  }   
+
+  if (pKa_Donor == -999)
+  {
+    pKa_Donor <- suppressWarnings(get_physchem_param(
                                     "pKa_Donor",
                                     chem.cas=chem.cas,
                                     chem.name=chem.name,
                                     dtxsid=dtxsid))
-  if (!is.null(parameters))
-    if ("pKa_Donor" %in% names(parameters))
-      pKa_Donor <- parameters$pKa_Donor
-        
-  pKa_Accept <- suppressWarnings(get_physchem_param(
+  }
+  
+  if (pKa_Accept == -999)
+  {    
+    pKa_Accept <- suppressWarnings(get_physchem_param(
                                      "pKa_Accept",
                                      chem.cas=chem.cas,
                                      chem.name=chem.name,
                                      dtxsid=dtxsid))
-  if (!is.null(parameters))
-    if ("pKa_Accept" %in% names(parameters))
-      pKa_Accept <- parameters$pKa_Accept
+  }
+
+  if (is.na(MA))
+  {
+    if (any(!is.null(chem.cas),!is.null(chem.name),!is.null(dtxsid)))
+      MA <- suppressWarnings(10^(get_physchem_param("logMA",
+            chem.cas=chem.cas,
+            chem.name=chem.name,
+            dtxsid=dtxsid))) 
+    # If we don't have a measured value for membrane affintity, 
+    # use Yun & Edgington (2013):
+    if (is.na(MA))
+    {
+      MA <- calc_ma( chem.cas=chem.cas,
+            chem.name=chem.name,
+            dtxsid=dtxsid,
+            suppress.messages=suppress.messages)
+    }
+  }
   
-  MA <- suppressWarnings(10^(get_physchem_param("logMA",
-          chem.cas=chem.cas,
-          chem.name=chem.name,
-          dtxsid=dtxsid))) 
-  if (!is.null(parameters))
-    if ("MA" %in% names(parameters))
-      MA <- parameters$MA
-  
-  Fprotein <- physiology.data[
+  if (is.na(Fprotein))
+  {
+    Fprotein <- physiology.data[
                 which(physiology.data[,'Parameter'] ==
                   'Plasma Protein Volume Fraction'),
                 which(tolower(colnames(physiology.data)) == tolower(species))]
-  if (!is.null(parameters))
-    if ("Fprotein.plasma" %in% names(parameters))
-      Fprotein <- parameters$Fprotein.plasma
-  
-  plasma.pH <- 7.4
-  if (!is.null(parameters))
-    if ("plasma.pH" %in% names(parameters))
-      plasma.pH <- parameters$plasma.pH
-
-  alpha <- 0.001
-  if (!is.null(parameters))
-    if ("alpha" %in% names(parameters))
-      alpha <- parameters$alpha
-
-# Check if fup is a point value or a distribution, if a distribution, use the median:
-  if (nchar(fup.db) - nchar(gsub(",","",fup.db))==2) 
-  {
-    fup.point <- as.numeric(strsplit(fup.db,",")[[1]][1])
-    fup.dist <- fup.db
-    if (!suppress.messages) 
-      warning("Fraction unbound is provided as a distribution.")
-  } else {
-    fup.point <- fup.db
-    fup.dist <- NA 
   }
+  
+  if (is.na(plasma.pH)) plasma.pH <- 7.4
 
-# If species-specific fup is 0 try the human value:  
-  if (fup.point == 0 & tolower(species)!="human" & default.to.human) 
+  if (is.na(alpha)) alpha <- 0.001
+
+  # Get the central tendency (point estimate) and potentially the distribution
+  # quantiles for the fraction unbound in plasma (fup):
+  if (is.na(fup.point))
   {
-    if (!suppress.messages) 
-      warning(paste("Fraction unbound of zero for ",species,"replaced with human value."))
-     fup.db <- try(
-                get_invitroPK_param(
-                  "Funbound.plasma",
-                  "Human",
-                  chem.cas=chem.cas,
-                  chem.name=chem.name,
-                  dtxsid=dtxsid),
-                silent=TRUE)
-  # Check if fup is a point value or a distribution, if a distribution, use the median:
-    if (nchar(fup.db) - nchar(gsub(",","",fup.db))==2) 
-    {
-      fup.point <- as.numeric(strsplit(fup.db,",")[[1]][1])
-      fup.dist <- fup.db
-      if (!suppress.messages) 
-        warning("Fraction unbound is provided as a distribution.")
+    fup.list <- get_fup(
+        dtxsid=dtxsid,
+        chem.name=chem.name,
+        chem.cas=chem.cas,
+        species=species,
+        default.to.human=default.to.human,
+        force.human.fup=force.human.fup,
+        minimum.Funbound.plasma=minimum.Funbound.plasma,
+        suppress.messages=suppress.messages) 
+    fup.point <- fup.list$Funbound.plasma.point
+    fup.dist <- fup.list$Funbound.plasma.dist 
+  }
+ 
+  if (fup.point > 0)
+  {     
+    # Get the Pearce et al. (2017) lipid binding correction:       
+    fup.adjustment <- calc_fup_correction(fup.point,
+                                          parameters=parameters,
+                                          dtxsid=dtxsid,
+                                          chem.name=chem.name,
+                                          chem.cas=chem.cas,
+                                          default.to.human=default.to.human,
+                                          force.human.fup=force.human.fup,
+                                          suppress.messages=suppress.messages)
+  
+    # Apply the correction if requested:
+    if (adjusted.Funbound.plasma)
+    { 
+      fup.corrected <- apply_fup_adjustment(
+                         fup.point,
+                         fup.correction=fup.adjustment,
+                         suppress.messages=suppress.messages,
+                         minimum.Funbound.plasma=minimum.Funbound.plasma
+                         )
     } else {
-      fup.point <- fup.db
-      fup.dist <- NA 
-    }
-  }
-
-# We need a non-zero fup to make predictions:
-  if (fup.point == 0 & !suppress.messages)
-  {
-    if (tolower(species)!="human" & !default.to.human) 
-    {
-      warning("Fraction unbound = 0, cannot predict tissue partitioning (try default.to.human=TRUE?).")
-    } else warning("Fraction unbound = 0, cannot predict tissue partitioning.")
-  }
+      fup.corrected <- fup.point
+    } 
+  } else {
+    fup.adjustment <- NA
+    fup.corrected <- NA
+  } 
   
-# Calculate Pearce (2017) in vitro plasma binding correction:
-  if (force.human.fup) 
-    Flipid <- subset(
-                physiology.data,
-                Parameter == 'Plasma Effective Neutral Lipid Volume Fraction')[,
-                  which(colnames(physiology.data) == 'Human')]
-  else Flipid <- subset(
-                   physiology.data,
-                   Parameter=='Plasma Effective Neutral Lipid Volume Fraction')[,
-                     which(tolower(colnames(physiology.data)) == tolower(species))]
-  if (!is.null(parameters))
-    if ("Flipid" %in% names(parameters))
-      Flipid <- parameters$Flipid
+  if (is.na(fup.corrected)) stop(
+"fup is NA, Schmitt's method for tissue partition cannot be used.")
 
-  ion <- calc_ionization(
-           pH=plasma.pH,
-           pKa_Donor=pKa_Donor,
-           pKa_Accept=pKa_Accept)
-  dow <- Pow * (ion$fraction_neutral + 
-                alpha * ion$fraction_charged + 
-                ion$fraction_zwitter)
-  fup.corrected <- max(
-                     1 / ((dow) * Flipid + 1 / fup.point),
-                     minimum.Funbound.plasma) # Enforcing a sanity check on 
-                                               # plasma binding
-  
   outlist <- list(Funbound.plasma=fup.corrected,
                   unadjusted.Funbound.plasma=fup.point,
                   Funbound.plasma.dist=fup.dist,
-                  Funbound.plasma.adjustment=fup.corrected/fup.point,
+                  Funbound.plasma.adjustment=fup.adjustment,
                   Pow=Pow,
                   pKa_Donor=pKa_Donor,
                   pKa_Accept=pKa_Accept,
