@@ -39,8 +39,6 @@ calc_mc_css(chem.cas="15972-60-8",samples=NSAMP)
 set.seed(1234)
 calc_mc_css(dtxsid="DTXSID5041726",samples=NSAMP)
 
-
-
 #
 #
 # Now test that MC works across different models:
@@ -51,35 +49,6 @@ calc_mc_css(chem.cas="15972-60-8",model="1compartment",samples=NSAMP)
 set.seed(1234)
 calc_mc_css(chem.cas="15972-60-8",model="pbtk",samples=NSAMP)
 
-#
-#
-# Now do different MC sampling:
-set.seed(1234)
-# Standard HTTK Monte Carlo:
-calc_mc_css(chem.cas="90-43-7",model="pbtk",samples=NSAMP)
-set.seed(1234)
-# HTTK Monte Carlo with no measurment uncertainty (pre v1.10.0):
-calc_mc_css(chem.cas="90-43-7",
-  model="pbtk",
-  samples=NSAMP,
-  invitro.mc.arg.list = list(adjusted.Funbound.plasma = TRUE,
-    poormetab = TRUE, 
-    fup.censored.dist = FALSE, 
-    fup.lod = 0.01, 
-    fup.meas.cv = 0.0, 
-    clint.meas.cv = 0.0, 
-    fup.pop.cv = 0.3, 
-    clint.pop.cv = 0.3))
-set.seed(1234)
-# HTTK Monte Carlo with no HTTK-Pop physiological variability):
-calc_mc_css(chem.cas="90-43-7",model="pbtk",samples=NSAMP,httkpop=FALSE)
-set.seed(1234)
-# HTTK Monte Carlo with no in vitro uncertainty and variability):
-calc_mc_css(chem.cas="90-43-7",model="pbtk",samples=NSAMP,invitrouv=FALSE)
-set.seed(1234)
-# HTTK Monte Carlo with no HTTK-Pop and no in vitro uncertainty and variability):
-calc_mc_css(chem.cas="90-43-7",model="pbtk",samples=NSAMP,httkpop=FALSE,invitrouv=FALSE)
-
 # Should be the same as the mean result:
 calc_analytic_css(chem.cas="90-43-7",model="pbtk",output.units="mg/L")
 
